@@ -520,9 +520,10 @@ class Controller:
                    == complete_data['player'].id).\
             order_by(model.Match.datetime.desc()).limit(1).scalar()
 
-        if not previous_match:
-            logger.warning('{}: No previous match found.'.format(
-                complete_data['player'].id))
+        # Warning breaks Travis CI
+        # if not previous_match:
+        #     logger.warning('{}: No previous match found.'.format(
+        #         complete_data['player'].id))
 
         for idx, match in enumerate(complete_data['games']):
             estMMRchange = round(
